import React, {useEffect} from 'react';
import {Text, Pressable} from 'react-native';
import {
	NavigationContainer,
	useNavigationContainerRef,
} from '@react-navigation/native';
import {createNativeStackNavigator} from '@react-navigation/native-stack';
import SignIn from './screens/SignIn';
import useLoggedIn from './hooks/useLoggedIn';
import SignUp from './screens/SignUp';
import Buckets from './screens/Buckets';
import Settings from './screens/Settings';
import DirectoryDetails from './screens/DirectoryDetails';
import FileDetails from './screens/FileDetails';

const Stack = createNativeStackNavigator();

const Navigation = () => {
	const [isInitializing, user] = useLoggedIn();

	if (isInitializing) {
		return <Text>Loading...</Text>;
	}

	return (
		<NavigationContainer>
			<Stack.Navigator initialRouteName={!!user ? 'Buckets' : 'SignIn'}>
				<Stack.Screen
					name="SignIn"
					component={SignIn}
					options={{title: 'Sign In'}}
				/>
				<Stack.Screen
					name="SignUp"
					component={SignUp}
					options={{title: 'Sign Up'}}
				/>
				<Stack.Screen
					name="Buckets"
					component={Buckets}
					options={({navigation}) => ({
						title: 'S3 Buckets',
						headerRight: () => (
							<Pressable onPress={() => navigation.navigate('Settings')}>
								<Text style={{fontSize: 24, color: '#000000'}}>⚙</Text>
							</Pressable>
						),
					})}
				/>
				<Stack.Screen
					name="DirectoryDetails"
					component={DirectoryDetails}
					options={({route}) => ({
						title: route.params.dir,
					})}
				/>
				<Stack.Screen
					name="FileDetails"
					component={FileDetails}
					options={({route}) => ({
						title: route.params.file,
					})}
				/>
				<Stack.Screen
					name="Settings"
					component={Settings}
					options={{title: 'Settings'}}
				/>
			</Stack.Navigator>
		</NavigationContainer>
	);
};

export default Navigation;
