import React, {useCallback} from 'react';
import {StyleSheet, Text, Pressable} from 'react-native';
import {useNavigation} from '@react-navigation/native';

const Bucket = ({bucket}) => {
	const navigation = useNavigation();

	const onPress = useCallback(() => {
		navigation.navigate('DirectoryDetails', {bucket: bucket.Name, dir: '/'});
	}, [navigation, bucket]);

	return (
		<Pressable onPress={onPress} style={styles.root}>
			<Text style={styles.name}>{bucket.Name}</Text>
			<Text style={styles.createdAt}>
				Created at: {bucket.CreationDate.toISOString()}
			</Text>
		</Pressable>
	);
};

const styles = StyleSheet.create({
	root: {
		margin: 4,
		backgroundColor: '#CCCCCC',
		borderRadius: 5,
		padding: 12,
	},
	name: {
		fontSize: 16,
		fontWeight: 'bold',
		marginBottom: 8,
		color: '#000000',
	},
	createdAt: {
		fontSize: 12,
		color: '#444444',
	},
});

export default Bucket;
