import {useState, useCallback, useEffect} from 'react';
import {ToastAndroid} from 'react-native';
import firestore from '@react-native-firebase/firestore';
import useLoggedIn from './useLoggedIn';

const useSettings = () => {
	const [ready, user] = useLoggedIn();
	const [awsKeyId, setAwsKeyId] = useState('');
	const [awsSecretAccessKey, setAwsSecretAccessKey] = useState('');
	const [isLoaded, setIsLoaded] = useState(false);

	useEffect(() => {
		if (!isLoaded && user) {
			firestore()
				.collection('user-settings')
				.doc(user.uid)
				.get()
				.then(doc => {
					if (doc) {
						const data = doc.data();
						setAwsKeyId(data['aws.keyId']);
						setAwsSecretAccessKey(data['aws.secretAccessKey']);
					}
				})
				.catch(() => {})
				.finally(() => {
					setIsLoaded(true);
				});
		}
	}, [user]);

	const save = useCallback(() => {
		return firestore()
			.collection('user-settings')
			.doc(user.uid)
			.set({
				'aws.keyId': awsKeyId,
				'aws.secretAccessKey': awsSecretAccessKey,
			})
			.then(() => {
				ToastAndroid.show('Successfully saved settings', ToastAndroid.SHORT);
			})
			.catch(e => {
				console.log(e);
				ToastAndroid.show('Failed to save settings', ToastAndroid.SHORT);
				throw e;
			});
	}, [user, awsKeyId, awsSecretAccessKey]);

	return [
		isLoaded,
		save,
		awsKeyId,
		setAwsKeyId,
		awsSecretAccessKey,
		setAwsSecretAccessKey,
	];
};

export default useSettings;
