import React, {useState, useEffect} from 'react';
import {ScrollView, ToastAndroid} from 'react-native';
import {useRoute} from '@react-navigation/native';
import useS3 from '../hooks/useS3';
import Directory from '../components/Directory';
import File from '../components/File';

const DirectoryDetails = () => {
	const route = useRoute();
	const s3 = useS3();
	const [contents, setContents] = useState({dirs: [], files: []});

	useEffect(() => {
		if (s3 && !contents.length) {
			s3.listObjects(
				{
					Bucket: route.params.bucket,
					Prefix: route.params.dir == '/' ? '' : route.params.dir,
					Delimiter: '/',
					MaxKeys: 5000,
				},
				(err, data) => {
					if (err) {
						ToastAndroid.show(
							'Failed to fetch directory contents',
							ToastAndroid.SHORT,
						);
						return;
					}

					setContents({dirs: data.CommonPrefixes, files: data.Contents});
				},
			);
		}
	}, [s3]);

	return (
		<ScrollView>
			{contents.dirs.map(dir => (
				<Directory
					key={'dir-' + dir.Prefix}
					bucket={route.params.bucket}
					dir={dir}
				/>
			))}
			{contents.files.map(file => (
				<File
					key={'file-' + file.Key}
					bucket={route.params.bucket}
					file={file}
				/>
			))}
		</ScrollView>
	);
};

export default DirectoryDetails;
